package com.fastbee.waterele.mapper;

import java.util.List;
import com.fastbee.waterele.domain.MaRechargerecord;

/**
 * 充值记录Mapper接口
 *
 * @author kerwincui
 * @date 2024-08-12
 */
public interface MaRechargerecordMapper
{
    /**
     * 查询充值记录
     *
     * @param id 充值记录主键
     * @return 充值记录
     */
    public MaRechargerecord selectMaRechargerecordById(Long id);

    /**
     * 查询充值记录列表
     *
     * @param maRechargerecord 充值记录
     * @return 充值记录集合
     */
    public List<MaRechargerecord> selectMaRechargerecordList(MaRechargerecord maRechargerecord);

    /**
     * 新增充值记录
     *
     * @param maRechargerecord 充值记录
     * @return 结果
     */
    public int insertMaRechargerecord(MaRechargerecord maRechargerecord);

    /**
     * 修改充值记录
     *
     * @param maRechargerecord 充值记录
     * @return 结果
     */
    public int updateMaRechargerecord(MaRechargerecord maRechargerecord);

    /**
     * 删除充值记录
     *
     * @param id 充值记录主键
     * @return 结果
     */
    public int deleteMaRechargerecordById(Long id);

    /**
     * 批量删除充值记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMaRechargerecordByIds(Long[] ids);

    int updateByCardNumAndAreaCode(MaRechargerecord maRechargerecord);
}
